#!/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_ddx0rx7y7f/croots/recipe/gdal-split_1659452593465/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/bin/python
# EASY-INSTALL-SCRIPT: 'GDAL==3.0.2','esri2wkt.py'
__requires__ = 'GDAL==3.0.2'
__import__('pkg_resources').run_script('GDAL==3.0.2', 'esri2wkt.py')
